@@ -15,7 +15,7 @@ def rawselect(
     default: Optional[Text] = None,
     qmark: Text = DEFAULT_QUESTION_PREFIX,
     style: Optional[Style] = None,
-    **kwargs: Any
+    **kwargs: Any,
 ) -> Question:
     """Ask the user to select one item from a list of choices using shortcuts.
 
